@@ -10,4 +10,4 @@ else
   echo Error
 fi
 chmod +x miniconda.sh
-./miniconda.sh -b
+bash ./miniconda.sh -b
