@@ -22,17 +22,13 @@ set +v
 source activate $CONDA_ENV
 set -v
 
-# Install llvmdev (separate channel, for now)
-if [ "$LLVM" == "16" ]; then
-    $CONDA_INSTALL -c conda-forge llvmdev="16"
-else
-    $CONDA_INSTALL -c numba llvmdev="15.*"
-fi
+# Install llvmdev 20
+$CONDA_INSTALL  numba/label/dev::llvmdev=20
 
 # Install the compiler toolchain, for osx, bootstrapping needed
 # which happens in build.sh
-if [[ $(uname) == Linux ]]; then
-$CONDA_INSTALL gcc_linux-64 gxx_linux-64
+if [[ "$(uname)" == "Linux" ]]; then
+    $CONDA_INSTALL gcc_linux-64 gxx_linux-64
 fi
 
 # Install dependencies for code coverage (codecov.io)
