@@ -10,15 +10,17 @@ set -v -e
 python --version
 
 if [ "$OPAQUE_POINTERS" == "yes" ]; then
-    export LLVMLITE_ENABLE_OPAQUE_POINTERS=1
-    echo "Testing with opaque pointers enabled"
+    export LLVMLITE_ENABLE_IR_LAYER_TYPED_POINTERS=0
+    echo "Testing with IR layer opaque pointers enabled"
 else
-    echo "Testing with opaque pointers disabled"
+    echo "Testing with IR layer opaque pointers disabled"
 fi
 
 if [ "$WHEEL" == "yes" ]; then
     cd dist
     python -m llvmlite.tests -v
+elif [ "$DIST_TEST" == "yes" ]; then
+    LLVMLITE_DIST_TEST=1 python runtests.py -v
 else
     python runtests.py -v
 fi
