@@ -13,20 +13,18 @@ sourceroot=$(pwd)
 pyver=$2
 envname="llvmbase"
 outputdir="/root/llvmlite/docker_output"
+LLVMDEV_ARTIFACT_PATH=${3:-""}
 
 ls -l /opt/python/$pyver/bin
 
-conda create -y -n $envname 
+conda create -y -n $envname
 conda activate $envname
 # Install llvmdev
 
-if [[ $(uname -m) == "aarch64" ]] ; then
-    conda install -y numba/label/manylinux_2_28::llvmdev --no-deps
-elif [[ $(uname -m) == "x86_64" ]] ; then
-    conda install -y numba/label/manylinux_2_17::llvmdev --no-deps
+if [ -n "$LLVMDEV_ARTIFACT_PATH" ] && [ -d "$LLVMDEV_ARTIFACT_PATH" ]; then
+    conda install -y "$LLVMDEV_ARTIFACT_PATH"/llvmdev-*.conda --no-deps
 else
-    echo "Error: Unsupported architecture: $(uname -m)"
-    exit 1
+    conda install -y -c defaults numba/label/llvm20-wheel::llvmdev=20 --no-deps
 fi
 
 # Prepend builtin Python Path
@@ -40,6 +38,9 @@ pip install setuptools
 # Clean up
 python setup.py clean
 
+# Configure build via env vars
+export LLVMLITE_PACKAGE_FORMAT="wheel"
+
 # Build wheel
 distdir=$outputdir/dist_$(uname -m)_$pyver
 rm -rf $distdir
@@ -51,8 +52,3 @@ auditwheel --verbose repair *.whl
 
 cd wheelhouse
 ls
-
-
-# Verify & Test
-pip install *.whl
-python -m llvmlite.tests -vb
