@@ -2,11 +2,10 @@
 Classes that are LLVM types
 """
 
-from __future__ import print_function, absolute_import
-
 import struct
 
-from ._utils import _StrCaching
+from llvmlite import ir_layer_typed_pointers_enabled
+from llvmlite.ir._utils import _StrCaching
 
 
 def _wrapname(x):
@@ -32,12 +31,12 @@ class Type(_StrCaching):
     def __ne__(self, other):
         return not (self == other)
 
-    def _get_ll_pointer_type(self, target_data, context=None):
+    def _get_ll_global_value_type(self, target_data, context=None):
         """
         Convert this type object to an LLVM type.
         """
-        from . import Module, GlobalVariable
-        from ..binding import parse_assembly
+        from llvmlite.ir import Module, GlobalVariable
+        from llvmlite.binding import parse_assembly
 
         if context is None:
             m = Module()
@@ -45,22 +44,26 @@ class Type(_StrCaching):
             m = Module(context=context)
         foo = GlobalVariable(m, self, name="foo")
         with parse_assembly(str(m)) as llmod:
-            return llmod.get_global_variable(foo.name).type
+            return llmod.get_global_variable(foo.name).global_value_type
 
     def get_abi_size(self, target_data, context=None):
         """
         Get the ABI size of this type according to data layout *target_data*.
         """
-        llty = self._get_ll_pointer_type(target_data, context)
-        return target_data.get_pointee_abi_size(llty)
+        llty = self._get_ll_global_value_type(target_data, context)
+        return target_data.get_abi_size(llty)
+
+    def get_element_offset(self, target_data, ndx, context=None):
+        llty = self._get_ll_global_value_type(target_data, context)
+        return target_data.get_element_offset(llty, ndx)
 
     def get_abi_alignment(self, target_data, context=None):
         """
         Get the minimum ABI alignment of this type according to data layout
         *target_data*.
         """
-        llty = self._get_ll_pointer_type(target_data, context)
-        return target_data.get_pointee_abi_alignment(llty)
+        llty = self._get_ll_global_value_type(target_data, context)
+        return target_data.get_abi_alignment(llty)
 
     def format_constant(self, value):
         """
@@ -80,7 +83,7 @@ class Type(_StrCaching):
         """
         Create a LLVM constant of this type with the given Python value.
         """
-        from . import Constant
+        from llvmlite.ir import Constant
         return Constant(self, value)
 
 
@@ -111,31 +114,75 @@ class LabelType(Type):
 class PointerType(Type):
     """
     The type of all pointer values.
+    By default (without specialisation) represents an opaque pointer.
     """
+    is_opaque = True
     is_pointer = True
     null = 'null'
 
-    def __init__(self, pointee, addrspace=0):
-        assert not isinstance(pointee, VoidType)
-        self.pointee = pointee
+    # Factory to create typed or opaque pointers based on `pointee'.
+    def __new__(cls, pointee=None, addrspace=0):
+        if cls is PointerType and pointee is not None:
+            return super().__new__(_TypedPointerType)
+        return super(PointerType, cls).__new__(cls)
+
+    def __init__(self, addrspace=0):
         self.addrspace = addrspace
 
     def _to_string(self):
         if self.addrspace != 0:
-            return "{0} addrspace({1})*".format(self.pointee, self.addrspace)
+            return "ptr addrspace({0})".format(self.addrspace)
         else:
-            return "{0}*".format(self.pointee)
+            return "ptr"
 
     def __eq__(self, other):
-        if isinstance(other, PointerType):
-            return (self.pointee, self.addrspace) == (other.pointee,
-                                                      other.addrspace)
-        else:
-            return False
+        return (isinstance(other, PointerType) and
+                self.addrspace == other.addrspace)
 
     def __hash__(self):
         return hash(PointerType)
 
+    @property
+    def intrinsic_name(self):
+        return 'p%d' % self.addrspace
+
+    @classmethod
+    def from_llvm(cls, typeref, ir_ctx):
+        """
+        Create from a llvmlite.binding.TypeRef
+        """
+        return cls()
+
+
+class _TypedPointerType(PointerType):
+    """
+    The type of typed pointer values. To be removed eventually.
+    """
+
+    def __init__(self, pointee, addrspace=0):
+        super(_TypedPointerType, self).__init__(addrspace)
+        assert pointee is not None
+        assert not isinstance(pointee, VoidType)
+        self.pointee = pointee
+        self.is_opaque = False
+
+    def _to_string(self):
+        if ir_layer_typed_pointers_enabled:
+            return "{0}*".format(self.pointee) if self.addrspace == 0 else \
+                   "{0} addrspace({1})*".format(self.pointee, self.addrspace)
+        return super(_TypedPointerType, self)._to_string()
+
+    # This implements ``isOpaqueOrPointeeTypeEquals''.
+    def __eq__(self, other):
+        if isinstance(other, _TypedPointerType):
+            return (self.pointee, self.addrspace) == (other.pointee,
+                                                      other.addrspace)
+        return (isinstance(other, PointerType) and
+                self.addrspace == other.addrspace)
+
+    def __hash__(self):
+        return hash(_TypedPointerType)
+
     def gep(self, i):
         """
         Resolve the type of the i-th element (for getelementptr lookups).
@@ -146,7 +193,9 @@ class PointerType(Type):
 
     @property
     def intrinsic_name(self):
-        return 'p%d%s' % (self.addrspace, self.pointee.intrinsic_name)
+        if ir_layer_typed_pointers_enabled:
+            return 'p%d%s' % (self.addrspace, self.pointee.intrinsic_name)
+        return super(_TypedPointerType, self).intrinsic_name
 
 
 class VoidType(Type):
@@ -163,6 +212,13 @@ class VoidType(Type):
     def __hash__(self):
         return hash(VoidType)
 
+    @classmethod
+    def from_llvm(cls, typeref, ir_ctx):
+        """
+        Create from a llvmlite.binding.TypeRef
+        """
+        return cls()
+
 
 class FunctionType(Type):
     """
@@ -196,6 +252,17 @@ class FunctionType(Type):
     def __hash__(self):
         return hash(FunctionType)
 
+    @classmethod
+    def from_llvm(cls, typeref, ir_ctx):
+        """
+        Create from a llvmlite.binding.TypeRef
+        """
+        params = tuple(x.as_ir(ir_ctx=ir_ctx)
+                       for x in typeref.get_function_parameters())
+        ret = typeref.get_function_return().as_ir(ir_ctx=ir_ctx)
+        is_vararg = typeref.is_function_vararg
+        return cls(ret, params, is_vararg)
+
 
 class IntType(Type):
     """
@@ -203,6 +270,7 @@ class IntType(Type):
     """
     null = '0'
     _instance_cache = {}
+    width: int
 
     def __new__(cls, bits):
         # Cache all common integer types
@@ -245,10 +313,22 @@ class IntType(Type):
         else:
             return str(val)
 
+    def wrap_constant_value(self, val):
+        if val is None:
+            return 0
+        return val
+
     @property
     def intrinsic_name(self):
         return str(self)
 
+    @classmethod
+    def from_llvm(cls, typeref, ir_ctx):
+        """
+        Create from a llvmlite.binding.TypeRef
+        """
+        return IntType(typeref.type_width)
+
 
 def _as_float(value):
     """
@@ -257,6 +337,17 @@ def _as_float(value):
     return struct.unpack('f', struct.pack('f', value))[0]
 
 
+def _as_half(value):
+    """
+    Truncate to half-precision float.
+    """
+    try:
+        return struct.unpack('e', struct.pack('e', value))[0]
+    except struct.error:
+        # 'e' only added in Python 3.6+
+        return _as_float(value)
+
+
 def _format_float_as_hex(value, packfmt, unpackfmt, numdigits):
     raw = struct.pack(packfmt, float(value))
     intrep = struct.unpack(unpackfmt, raw)[0]
@@ -287,6 +378,27 @@ class _BaseFloatType(Type):
     def _create_instance(cls):
         cls._instance_cache = super(_BaseFloatType, cls).__new__(cls)
 
+    @classmethod
+    def from_llvm(cls, typeref, ir_ctx):
+        """
+        Create from a llvmlite.binding.TypeRef
+        """
+        return cls()
+
+
+class HalfType(_BaseFloatType):
+    """
+    The type for single-precision floats.
+    """
+    null = '0.0'
+    intrinsic_name = 'f16'
+
+    def __str__(self):
+        return 'half'
+
+    def format_constant(self, value):
+        return _format_double(_as_half(value))
+
 
 class FloatType(_BaseFloatType):
     """
@@ -316,7 +428,7 @@ class DoubleType(_BaseFloatType):
         return _format_double(value)
 
 
-for _cls in (FloatType, DoubleType):
+for _cls in (HalfType, FloatType, DoubleType):
     _cls._create_instance()
 
 
@@ -335,6 +447,67 @@ class _Repeat(object):
             raise IndexError(item)
 
 
+class VectorType(Type):
+    """
+    The type for vectors of primitive data items (e.g. "<f32 x 4>").
+    """
+
+    def __init__(self, element, count):
+        self.element = element
+        self.count = count
+
+    @property
+    def elements(self):
+        return _Repeat(self.element, self.count)
+
+    def __len__(self):
+        return self.count
+
+    def _to_string(self):
+        return "<%d x %s>" % (self.count, self.element)
+
+    def __eq__(self, other):
+        if isinstance(other, VectorType):
+            return self.element == other.element and self.count == other.count
+
+    def __hash__(self):
+        # TODO: why does this not take self.element/self.count into account?
+        return hash(VectorType)
+
+    def __copy__(self):
+        return self
+
+    def format_constant(self, value):
+        itemstring = ", " .join(["{0} {1}".format(x.type, x.get_reference())
+                                 for x in value])
+        return "<{0}>".format(itemstring)
+
+    def wrap_constant_value(self, values):
+        from . import Value, Constant
+        if not isinstance(values, (list, tuple)):
+            if isinstance(values, Constant):
+                if values.type != self.element:
+                    raise TypeError("expected {} for {}".format(
+                        self.element, values.type))
+                return (values, ) * self.count
+            return (Constant(self.element, values), ) * self.count
+        if len(values) != len(self):
+            raise ValueError("wrong constant size for %s: got %d elements"
+                             % (self, len(values)))
+        return [Constant(ty, val) if not isinstance(val, Value) else val
+                for ty, val in zip(self.elements, values)]
+
+    @classmethod
+    def from_llvm(cls, typeref, ir_ctx):
+        """
+        Create from a llvmlite.binding.TypeRef
+        """
+        [elemtyperef] = typeref.elements
+        elemty = elemtyperef.as_ir(ir_ctx=ir_ctx)
+        count = typeref.element_count
+        return cls(elemty, count)
+
+
 class Aggregate(Type):
     """
     Base class for aggregate types.
@@ -392,6 +565,16 @@ class ArrayType(Aggregate):
                                  for x in value])
         return "[{0}]".format(itemstring)
 
+    @classmethod
+    def from_llvm(cls, typeref, ir_ctx):
+        """
+        Create from a llvmlite.binding.TypeRef
+        """
+        [elemtyperef] = typeref.elements
+        elemty = elemtyperef.as_ir(ir_ctx=ir_ctx)
+        count = typeref.element_count
+        return cls(elemty, count)
+
 
 class BaseStructType(Aggregate):
     """
@@ -456,6 +639,17 @@ class BaseStructType(Aggregate):
         else:
             return textrepr
 
+    @classmethod
+    def from_llvm(cls, typeref, ir_ctx):
+        """
+        Create from a llvmlite.binding.TypeRef
+        """
+        if typeref.is_literal_struct:
+            elems = [el.as_ir(ir_ctx=ir_ctx) for el in typeref.elements]
+            return cls(elems, typeref.is_packed_struct)
+        else:
+            return ir_ctx.get_identified_type(typeref.name)
+
 
 class LiteralStructType(BaseStructType):
     """
@@ -478,7 +672,8 @@ class LiteralStructType(BaseStructType):
 
     def __eq__(self, other):
         if isinstance(other, LiteralStructType):
-            return self.elements == other.elements
+            return (self.elements == other.elements
+                    and self.packed == other.packed)
 
     def __hash__(self):
         return hash(LiteralStructType)
@@ -522,7 +717,8 @@ class IdentifiedStructType(BaseStructType):
 
     def __eq__(self, other):
         if isinstance(other, IdentifiedStructType):
-            return self.name == other.name
+            return (self.name == other.name
+                    and self.packed == other.packed)
 
     def __hash__(self):
         return hash(IdentifiedStructType)
